package
{
	import flash.display.Sprite;
	import flash.display.Graphics;
	import Vera;

	
	public class Sign extends Sprite
	{
		private var w:int; // largeur de l affichage
		private var h:int; // hauteur de l affichage
		private var a:String; // forme de signal
		private var f:Number; // frequence du signal
		private var t:int; // echelle temporelle
		private var u:Number; // tension du signal (amplitude)
		private var o:Number; // offset du signal (positif ou negatif)
		private var c:Number; // rapport cyclique
		private var m:Boolean; // affichage de la valeur moyenne
		private var r:Boolean; // remplissage à la valeur moyenne
		private var l:String; // legende de la courbe
		//private var s:Sprite; // spot lumineux : pas implementé par manque de temps
		
		public function Sign(w:int, h:int, a:String, f:Number, u:Number, o:Number, c:Number, m:Boolean, r:Boolean, l:String = ''):void
		{
			// recuperation des parametres
			this.w = w;
			this.h = h;
			this.a = a;
			this.f = f;
			this.u = u;
			this.o = o;
			this.c = c;
			this.m = m;
			this.r = r;
			this.l = l;
			
			if(this.f < 5) // determination de l echelle horizontale
			{
				this.t=1;
			}
			else if(this.f < 50)
			{
				this.f = this.f/10;
				this.t = 10;
			}
			else if(this.f < 500)
			{
				this.f = this.f/100;
				this.t = 100;
			}
			else if(this.f < 5000)
			{
				this.f = this.f/1000;
				this.t = 1000;
			}
			else
			{
				this.f = this.f/10000;
				this.t = 10000;
			}
			
			this.dessin(); // affichage
			
		}
		
		// getteurs
		public function getAmp():Number
		{
			return this.u;
		}
		public function getForm():String
		{
			return this.a;
		}
		public function getOff():Number
		{
			return this.o;
		}
		public function getRap():Number
		{
			return this.c;
		}
		public function getFreq():Number
		{
			return this.f;
		}
		public function getPas():int
		{
			return this.t;
		}
		public function setForm(a:String):void
		{
			this.a = a;
			this.dessin();
		}
		
		// setteurs
		public function setFreq(f:Number):void
		{
			this.f = f;
			this.dessin();
		}
		public function setPas(t:int):void
		{
			this.t = t;
			this.dessin();
		}
		public function setAmp(u:Number):void
		{
			this.u = u;
			this.dessin();
		}
		public function setOff(o:Number):void
		{
			this.o = o;
			this.dessin();
		}
		public function setRap(c:Number):void
		{
			this.c = c;
			this.dessin();
		}
		
		// affichage
		public function dessin():void
		{
			// reinitialisation
			var b:int = this.numChildren;
			var j:int;
			for(j = 0; j < b; j++)
			{
				this.removeChildAt(0);
			}
			this.graphics.clear();
			
			
			// dessin du spot
			/*s.beginFill(0x00bb99);
			s.graphics.drawCircle(0, 0, 5, 5);
			this.addChild(s);*/
			
			// remplissage a la valeur moyenne
			if(r == true)
			{
				//this.graphics.beginFill(0xDDDDDD);
			}
			
			// dessin de la courbe
			var i:Number;
			if(a == 's') // sinusoide propre grace a mr dhoutau
			{
				this.graphics.lineStyle(2, 0x00bb99);
				
				this.graphics.moveTo(0,h/2 - (h/40)*u*Math.sin((-3/2)*Math.PI*2*f)-(o*h/40));
				for (var x:int=0; x <=w; x++) {
					var temps:Number = -3/2 + (3/w)*x;
					var y:int = h/2 - (h/40)*u*Math.sin(temps*Math.PI*2*f)-(o*h/40);
					this.graphics.lineTo(x,y);
				}
			}
			else if(a == 'c') // creneau moins propre
			{
				this.graphics.lineStyle(2, 0x00bb99);
				this.graphics.moveTo(0, (h/2)-((u/40)*h)-(o*h/40)-(1-2*c)*u*(h/40));
				for(i = 0; i < 6*f; i = i + 0.01)
				{
					if((((i/2)%1)*((0.5)/c))<1)
					{
						this.graphics.lineTo((w/(6*f))*i, (u*(h/20))*Math.round(((i/2)%1)*((0.5)/c)) + (h/2)-((u/40)*h)-(o*h/40)-(1-2*c)*u*(h/40));
					}
					else
					{
						this.graphics.lineTo((w/(6*f))*i, (u*(h/20)) + (h/2)-((u/40)*h)-(o*h/40)-(1-2*c)*u*(h/40));
					}
				}
			}
			else if(a == 't') // triangle beaucoup moins propre
			{
				this.graphics.lineStyle(2, 0x00bb99);
				this.graphics.moveTo(0, (h/2)-((u/40)*h)-(o*h/40));
				for(i = 0; i < 6*f; i = i + 0.01)
				{
					this.graphics.lineTo((w/(6*f))*i, (u*(h/20))*((i-Math.floor(i))*Math.pow((-1),Math.floor(i))+Math.floor(i%2)) + (h/2)-((u/40)*h)-(o*h/40));
				}
			}
			
			// affichage de la valeur moyenne
			if(m == true)
			{
				this.graphics.lineStyle(2, 0x00bb99);
				this.graphics.moveTo(0, (h/2)-(o*h/40));
				this.graphics.lineTo(w, (h/2)-(o*h/40));
			}
			// dessin du repere
			this.graphics.lineStyle(1, 0x000000);
			this.graphics.moveTo(w/2, 0);
			this.graphics.lineTo(w/2, h);
			this.graphics.moveTo(0, h/2);
			this.graphics.lineTo(w, h/2);
			
			// affichage des graduations
			this.graphics.moveTo((w/2)-5, h/4);
			this.graphics.lineTo((w/2)+5, h/4);
			this.graphics.moveTo((w/2)-5, 3*h/4);
			this.graphics.lineTo((w/2)+5, 3*h/4);
			this.graphics.moveTo(w/6, (h/2)-5);
			this.graphics.lineTo(w/6, (h/2)+5);
			this.graphics.moveTo(5*w/6, (h/2)-5);
			this.graphics.lineTo(5*w/6, (h/2)+5);
			
			// affichage des echelles
			var ey:Vera = new Vera('10 V');
			ey.x = (w/2)-40;
			ey.y = (h/4)-10;
			this.addChild(ey);
			var ex:Vera = new Vera((1/t).toString() + ' s');			
			ex.x = 5*w/6;
			ex.y = (h/2);
			this.addChild(ex);
			
			// affichage de la legende
			if(l != '')
			{
				var k:Vera = new Vera(l, w, 'c');
				k.y = h;
				this.addChild(k);
			}
		}
	}
}